@@ -1,6 +1,6 @@
-use crate::trim_overlap::trim_overlapping_pafs;
-
 use super::bed;
+use super::myio;
+use super::trim_overlap::trim_overlapping_pafs;
 use core::{fmt, panic};
 use itertools::Itertools;
 use lazy_static::lazy_static;
@@ -10,8 +10,7 @@ use rust_htslib::bam::record::Cigar::*;
 use rust_htslib::bam::record::CigarString;
 use rust_htslib::bam::record::*;
 use std::collections::{HashMap, HashSet};
-use std::fs;
-use std::io;
+use std::convert::TryFrom;
 use std::io::BufRead;
 use std::str::FromStr;
 use std::usize;
@@ -53,22 +52,15 @@ impl Paf {
     ///
     /// ```
     pub fn from_file(file_name: &str) -> Paf {
-        // open the paf file
-        let paf_file: Box<dyn io::Read> = match file_name {
-            "-" => Box::new(io::stdin()),
-            _ => Box::new(fs::File::open(file_name).expect("Unable to open paf file")),
-        };
+        let paf_file = myio::reader(file_name);
         let mut paf = Paf::new();
-        //let mut records = Vec::new();
         // read the paf recs into a vector
-        for (index, line) in io::BufReader::new(paf_file).lines().enumerate() {
+        for (index, line) in paf_file.lines().enumerate() {
+            log::trace!("{:?}", line);
             match PafRecord::new(&line.unwrap()) {
                 Ok(rec) => {
-                    //eprint!("\rReading PAF entry # {}", index);
+                    log::debug!("Reading PAF entry # {}", index);
                     paf.records.push(rec);
-                    //let q_name = rec.q_name.clone();
-                    //let rec = paf.records.last().expect("must have inserted at least one");
-                    //(*paf.records_by_contig.entry(q_name).or_insert(Vec::new())).push(x);
                 }
                 Err(_) => eprintln!("\nUnable to parse PAF record. Skipping line {}", index + 1),
             }
@@ -206,7 +198,7 @@ impl Paf {
     }
 
     /// Identify overlapping pairs in Paf set
-    pub fn overlapping_paf_recs(&mut self) {
+    pub fn overlapping_paf_recs(&mut self, match_score: i32, diff_score: i32, indel_score: i32) {
         let mut overlap_pairs = Vec::new();
         self.records.sort_by_key(|rec| rec.q_name.clone());
 
@@ -247,13 +239,13 @@ impl Paf {
             let mut right = self.records[overlap_pairs[0].2].clone();
             left.aligned_pairs();
             right.aligned_pairs();
-            trim_overlapping_pafs(&mut left, &mut right);
+            trim_overlapping_pafs(&mut left, &mut right, match_score, diff_score, indel_score);
             log::trace!("{}", left);
             log::trace!("{}", right);
             self.records[overlap_pairs[0].1] = left;
             self.records[overlap_pairs[0].2] = right;
             // recursively call for next overlap
-            self.overlapping_paf_recs();
+            self.overlapping_paf_recs(match_score, diff_score, indel_score);
         }
     }
 
@@ -346,7 +338,10 @@ impl PafRecord {
             //    cigar = cs_to_cigar(value)?;
             //} else
             if tag == "cg" && cigar.len() == 0 {
-                cigar = cigar_from_str(value)?;
+                log::trace!("parsing cigar of length: {}", value.len());
+                //cigar = cigar_from_str(value)?;
+                cigar =
+                    CigarString::try_from(value.as_bytes()).expect("Unable to parse cigar string.");
             } else {
                 tags.push('\t');
                 tags.push_str(token);
@@ -379,6 +374,7 @@ impl PafRecord {
         Ok(rec)
     }
 
+    #[must_use]
     pub fn small_copy(&self) -> PafRecord {
         PafRecord {
             q_name: self.q_name.clone(),
